API Reference — QuadratiK 1.0.0 documentation

Skip to main content
`Ctrl`+`K`

# API Reference

## Kernel Test

`KernelTest`([h, method, num_iter, b, ...]) | Class for performing the kernel-based quadratic distance Goodness-of-fit tests using the Gaussian kernel with tuning parameter h.
`select_h`(x[, y, alternative, method, b, ...]) | This function computes the kernel bandwidth of the Gaussian kernel for the one sample, two-sample and ksample kernel-based quadratic distance (KBQD) tests.

## Poisson Kernel Test

`PoissonKernelTest`([rho, num_iter, quantile, ...]) | Class for Poisson kernel-based quadratic distance test of Uniformity on the Sphere

## Spherical Clustering

`PKBC`([num_clust, max_iter, stopping_rule, ...]) | Poisson kernel-based clustering on the Sphere.
`PKBD`() | Class for estimating density and generating samples of Poisson-kernel based distribution (PKBD).

## User Interface

`UI`() | The UI class is a user interface class that runs a Streamlit dashboard using asyncio.

## Datasets

`load_wireless_data`([desc, return_X_y, ...]) | The wireless data frame has 2000 rows and 8 columns.

## Tools

`sample_hypersphere`([npoints, ndim, random_state]) | Generate random samples from the hypersphere
`stats`(x[, y]) | The stats function calculates statistics for one or multiple groups of data.
`qq_plot`(x[, y, dist]) | The function qq_plot is used to create a quantile-quantile plot, either for a single sample or for two samples.
`sphere3d`(x[, y]) | The function sphere3d creates a 3D scatter plot with a sphere as the surface and data points plotted on it.
`plot_clusters_2d`(x[, y]) | This function plots a 2D scatter plot of data points, with an optional argument to color the points based on a cluster label, and also plots a unit circle.